@@ -398,8 +398,14 @@ def main():
 	__dsc = '%s <by d0n@janeiskla.de> manages pavlov servers commands via it\'s rcon like admin interface'%__me
 	cfgdir = expanduser('~/.config/%s'%__me)
 	cacdir = expanduser('~/.cache/%s'%__me)
-	makedirs(cfgdir)
-	makedirs(cacdir)
+	try:
+		makedirs(cfgdir)
+	except FileExistsError:
+		pass
+	try:
+		makedirs(cacdir)
+	except FileExistsError:
+		pass
 	if not isfile('%s/pavlovadm.conf'%cfgdir):
 		with open('usr/local/share/pavlovadm/pavlovadm.conf', 'r') as lfh, open('%s/pavlovadm.conf'%cfgdir, 'w+') as gfh:
 			gfh.write(lfh.read())
